#
# spec file for package maven-file-management
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-file-management
Version:        3.2.0
Release:        1.1
Summary:        Maven File Management API
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/file-management
Source0:        https://repo1.maven.org/maven2/org/apache/maven/shared/file-management/%{version}/file-management-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-lib
BuildRequires:  modello >= 2.0.0
BuildRequires:  plexus-utils
BuildRequires:  plexus-xml
BuildRequires:  slf4j
BuildRequires:  unzip
BuildArch:      noarch

%description
Provides a component for plugins to easily resolve project dependencies.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n file-management-%{version}
cp %{SOURCE1} build.xml

%pom_add_dep org.codehaus.plexus:plexus-xml:3.0.0

%build
mkdir -p lib
build-jar-repository -s lib \
    commons-io \
    maven/maven-plugin-api \
    plexus/utils \
    plexus/xml \
    slf4j/api

%{ant} \
    jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/file-management-%{version}.jar %{buildroot}%{_javadir}/%{name}/file-management.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/file-management.pom
%add_maven_depmap %{name}/file-management.pom %{name}/file-management.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Sat Apr 19 2025 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 3.2.0
  * New features and improvements
    + Enable GitHub Issues
    + Add Release Drafter
    + MSHARED-1203: no longer need to shell out to create a symbolic
    link
    + Java 7 can detect symbolic links
  * Maintenance
    + Update site descriptor
    + Skip generating of xml reader and writer for FileSet
    + Use version of modello-maven-plugin from parent
    + Add PR Automation and Stale actions
    + MSHARED-1448: Refresh download page
    + remove duplicate tests and unneeded code
    + fix JUnit dependencies
    + MSHARED-1265: use JUnit assumptions
    + MSHARED-1203: use JUnit @TempDir
    + MSHARED-1264: Convert to JUnit5
    + Add GitHub Actions setup and Dependabot
  * Dependency updates
    + Bump commons-io:commons-io from 2.18.0 to 2.19.0
    + Bump org.apache.maven.shared:maven-shared-components from 43
    to 44
    + MSHARED-1380: Bump commons-io:commons-io from 2.17.0 to 2.18.0
    + MSHARED-1381: Bump
    org.apache.maven.shared:maven-shared-components from 42 to 43
    + MSHARED-1380: Bump commons-io:commons-io from 2.16.1 to 2.17.0
    + MSHARED-1380: Bump commons-io:commons-io from 2.13.0 to 2.16.1
    + MSHARED-1381: Upgrade parent pom to 42
    + Bump apache/maven-gh-actions-shared from 3 to 4
    + Bump org.junit:junit-bom from 5.10.1 to 5.10.2
    + Bump org.junit:junit-bom from 5.10.0 to 5.10.1
    + Bump org.junit:junit-bom from 5.9.3 to 5.10.0
    + MSHARED-1266: upgrade commons-io 2.11.0 --> 2.13.0
    + update to parent pom 39
* Wed Jun 12 2024 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 3.1.0
  * Changes:
    + remove vestigial file
    + deps: update JUnit
    + ignore .checkstyle
    + update plexus-utils
    + Remove dependency on maven-shared-io
    + Use try with resources
    + Remove deprecated methods in favor of Apache Commons IO
    + MSHARED-1090: Update module
* Thu May 16 2024 Fridrich Strba <fstrba@suse.com>
- Use sisu-plexus instead of plexus-containers-container-default
* Tue Apr  2 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Remove unnecessary dependency on xmvn tools and parent pom
* Fri May 13 2022 Fridrich Strba <fstrba@suse.com>
- Fix build with modello 2.0.0
* Mon Mar 21 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Tue Mar 26 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-file-management 3.0.0
- Generate and customize ant build.xml file
